@@ -18,6 +18,7 @@ import json
 from datetime import timezone
 from datetime import datetime
 import gzip
+import zipfile
 import os
 import io
 import shutil
@@ -39,6 +40,7 @@ import utils.file_search as search
 import utils.file_convert as convert
 import utils.file_image as image
 import utils.exiftool as exiftool
+import utils.file_compression as compression
 # from utils.dir import get_folders_ftp
 # import utils.string_utils as strUtils
 
@@ -60,6 +62,7 @@ def decompress(file_obj, compression="gzip"):
 
         [`compression`="gzip"] {string}
             The type of compression to use.
+            ["zipfile","gzip"]
 
         Return {list}
         ----------------------
@@ -122,8 +125,8 @@ def _decompress_single_file_gzip(file_path):
                 contents = decoder.read()
                 write.write(temp_path, contents)
     except gzip.BadGzipFile:
-        print(f"File is not compressed: {file_path}")
-        contents = read.read(file_path)
+        # print(f"File is not compressed: {file_path}")
+        return read.read(file_path)
 
     if contents is not False:
         # delete the compressed file
@@ -146,6 +149,7 @@ def _compress_single_file_gzip(file_path):
     return success
 
 
+
 def exists(file_path, **kwargs):
     '''
         Confirms that the file exists.
@@ -291,6 +295,7 @@ def gen_path_list(file_obj):
     return file_list
 
 
+
 def import_project_settings(file_name):
     '''
         Used to import a json file, same as just reading a json file.
@@ -806,6 +811,7 @@ def get_data(file_path, **kwargs):
         try:
             file_data = {}
             file_data['file_path'] = file_path
+            # @FIXME when extension and data_include is provided, but data_include does not have 'extension' it throws an error because it is missing data.
 
             if 'file_name' in data_include:
                 file_data['file_name'] = os.path.basename(file_path)
@@ -829,6 +835,7 @@ def get_data(file_path, **kwargs):
             return None
     else:
         logger.warning("Failed to find the file: %s", file_path)
+        return None
 
 
 def get_modified_time(file_path, ftp=None):
